@@ -1,7 +1,5 @@
 from datetime import datetime
-import json
 
-from django.conf import settings
 from django.core import mail
 from django.core.mail import EmailMultiAlternatives
 from django.core.management import call_command
@@ -298,10 +296,15 @@ class ConvertEventsToEmailsTest(TestCase):
 
     @freeze_time('2013-1-2')
     def test_bulk_multiple_events_only_following_false(self):
+        """
+        Handles bulk creating events and tests the unique constraint of the duplicated subscription which would cause
+        a bulk create error if it wasn't handled
+        """
         source = G(Source)
         e = G(Entity)
         other_e = G(Entity)
 
+        G(Subscription, entity=e, source=source, medium=self.email_medium, only_following=False)
         G(Subscription, entity=e, source=source, medium=self.email_medium, only_following=False)
         G(Subscription, entity=other_e, source=source, medium=self.email_medium, only_following=False)
         email_context = {
@@ -320,6 +323,35 @@ class ConvertEventsToEmailsTest(TestCase):
             self.assertEquals(email.subject, '')
             self.assertEquals(email.scheduled, datetime(2013, 1, 2))
 
+    @freeze_time('2013-1-2')
+    def test_bulk_multiple_events_only_following_true(self):
+        """
+        Handles bulk creating events and tests the unique constraint of the duplicated subscription which would cause
+        a bulk create error if it wasn't handled
+        """
+        source = G(Source)
+        e = G(Entity)
+        other_e = G(Entity)
+
+        G(Subscription, entity=e, source=source, medium=self.email_medium, only_following=True)
+        G(Subscription, entity=e, source=source, medium=self.email_medium, only_following=True)
+        G(Subscription, entity=other_e, source=source, medium=self.email_medium, only_following=True)
+        email_context = {
+            'entity_emailer_template': 'template',
+            'entity_emailer_subject': 'hi',
+        }
+        G(Event, source=source, context=email_context)
+        event = G(Event, source=source, context=email_context)
+        G(EventActor, event=event, entity=e)
+
+        EntityEmailerInterface.bulk_convert_events_to_emails()
+
+        email = Email.objects.get()
+        self.assertEquals(set(email.recipients.all()), set([e]))
+        self.assertEquals(email.event.context, email_context)
+        self.assertEquals(email.subject, '')
+        self.assertEquals(email.scheduled, datetime(2013, 1, 2))
+
     @freeze_time('2013-1-2')
     def test_multiple_events_only_following_true(self):
         source = G(Source)
@@ -367,11 +399,8 @@ class SendUnsentScheduledEmailsTest(TestCase):
         address_mock.return_value = ['test1@example.com', 'test2@example.com']
         g_email(context={}, scheduled=datetime.min)
         g_email(context={}, scheduled=datetime.min)
-
-        with patch(settings.EMAIL_BACKEND) as mock_connection:
-            EntityEmailerInterface.send_unsent_scheduled_emails()
-
-            self.assertEqual(2, mock_connection.return_value.__enter__.return_value.send_message.call_count)
+        EntityEmailerInterface.send_unsent_scheduled_emails()
+        self.assertEqual(len(mail.outbox), 2)
 
     @patch('entity_emailer.interface.pre_send')
     @patch('entity_emailer.interface.get_subscribed_email_addresses')
@@ -387,23 +416,21 @@ class SendUnsentScheduledEmailsTest(TestCase):
         email = g_email(context={
             'test': 'test'
         }, scheduled=datetime.min)
+        EntityEmailerInterface.send_unsent_scheduled_emails()
 
-        with patch(settings.EMAIL_BACKEND) as mock_connection:
-            EntityEmailerInterface.send_unsent_scheduled_emails()
+        # Assert that we sent the email
+        self.assertEqual(len(mail.outbox), 1)
 
-            # Assert that we sent the email
-            self.assertEqual(1, mock_connection.return_value.__enter__.return_value.send_message.call_count)
-
-            # Assert that we called the pre send signal with the proper values
-            name, args, kwargs = mock_pre_send.send.mock_calls[0]
-            self.assertEqual(kwargs['sender'], email.event.source.name)
-            self.assertEqual(kwargs['email'], email)
-            self.assertEqual(kwargs['event'], email.event)
-            self.assertEqual(kwargs['context'], {
-                'test': 'test',
-                'entity_emailer_id': str(email.view_uid)
-            })
-            self.assertIsInstance(kwargs['message'], EmailMultiAlternatives)
+        # Assert that we called the pre send signal with the proper values
+        name, args, kwargs = mock_pre_send.send.mock_calls[0]
+        self.assertEqual(kwargs['sender'], email.event.source.name)
+        self.assertEqual(kwargs['email'], email)
+        self.assertEqual(kwargs['event'], email.event)
+        self.assertEqual(kwargs['context'], {
+            'test': 'test',
+            'entity_emailer_id': str(email.view_uid)
+        })
+        self.assertIsInstance(kwargs['message'], EmailMultiAlternatives)
 
     @patch('entity_emailer.interface.get_subscribed_email_addresses')
     @patch.object(Event, 'render', spec_set=True)
@@ -412,12 +439,8 @@ class SendUnsentScheduledEmailsTest(TestCase):
         address_mock.return_value = ['test1@example.com', 'test2@example.com']
         from_address = 'test@example.com'
         g_email(context={}, from_address=from_address, scheduled=datetime.min)
-
-        with patch(settings.EMAIL_BACKEND) as mock_connection:
-            EntityEmailerInterface.send_unsent_scheduled_emails()
-
-            args = mock_connection.return_value.__enter__.return_value.send_message.call_args
-            self.assertEqual(args[0][0].from_email, from_address)
+        EntityEmailerInterface.send_unsent_scheduled_emails()
+        self.assertEqual(mail.outbox[0].from_email, from_address)
 
     @patch('entity_emailer.interface.get_subscribed_email_addresses')
     @patch.object(Event, 'render', spec_set=True)
@@ -469,57 +492,15 @@ class SendUnsentScheduledEmailsTest(TestCase):
         }, scheduled=datetime.min)
 
         # Send the emails
-        with patch(settings.EMAIL_BACKEND) as mock_connection:
-            EntityEmailerInterface.send_unsent_scheduled_emails()
+        EntityEmailerInterface.send_unsent_scheduled_emails()
 
-            # Assert that both emails were marked as sent
-            self.assertEqual(Email.objects.filter(sent__isnull=False).count(), 2)
+        # Assert that both emails were marked as sent
+        self.assertEqual(Email.objects.filter(sent__isnull=False).count(), 2)
 
-            # Assert that only one email is actually sent through backend
-            self.assertEquals(1, mock_connection.call_count)
-            # Assert that one email raised an exception
-            exception_email = Email.objects.get(sent__isnull=False, exception__isnull=False)
-            self.assertIsNotNone(exception_email)
-            self.assertTrue('Exception: test' in exception_email.exception)
-
-    @patch.object(Event, 'render', spec_set=True)
-    @patch('entity_emailer.interface.get_subscribed_email_addresses')
-    def test_send_exceptions(self, mock_get_subscribed_addresses, mock_render):
-        """
-        Verifies that when a single email raises an exception from within the backend, the batch is still
-        updated as sent and the failed email is saved with the exception
-        """
-        # Create test emails to send
-        g_email(context={}, scheduled=datetime.min)
-        failed_email = g_email(context={}, scheduled=datetime.min)
-        mock_get_subscribed_addresses.return_value = ['test1@example.com']
-        mock_render.return_value = ('foo', 'bar',)
-
-        # Verify baseline, namely that both emails are not marked as sent and that neither has an exception saved
-        self.assertEquals(2, Email.objects.filter(sent__isnull=True).count())
-
-        class TestEmailSendMessageException(Exception):
-            def to_dict(self):
-                return {'message': str(self)}
-
-        with patch(settings.EMAIL_BACKEND) as mock_connection:
-            # Mock side effects for sending emails
-            mock_connection.return_value.__enter__.return_value.send_message.side_effect = [
-                None,
-                TestEmailSendMessageException('test'),
-            ]
-
-            EntityEmailerInterface.send_unsent_scheduled_emails()
-
-        # Verify that both emails are marked as sent
-        self.assertEquals(2, Email.objects.filter(sent__isnull=False).count())
-        # Verify that the failed email was saved with the exception
-        actual_failed_email = Email.objects.get(sent__isnull=False, exception__isnull=False)
-        self.assertEquals(failed_email.id, actual_failed_email.id)
-        self.assertEquals(
-            'test: {}'.format(json.dumps({'message': 'test'})),
-            actual_failed_email.exception
-        )
+        # Assert that one email raised an exception
+        exception_email = Email.objects.get(sent__isnull=False, exception__isnull=False)
+        self.assertIsNotNone(exception_email)
+        self.assertTrue('Exception: test' in exception_email.exception)
 
 
 class CreateEmailObjectTest(TestCase):
